part of masamune;

/// Create extension methods for [PageRef] and [WidgetRef] to handle Query for prefs.
///
/// Prefs用のQueryを処理するための[PageRef]や[WidgetRef]の拡張メソッドを作成します。
extension MasamunePrefsExtensions on RefHasApp {
  /// Get state-preserved `SharedPreferences` by passing the [PrefsBase] code generated by the builder.
  ///
  /// All changes to `SharedPreferences` are monitored and the widgets used are updated when changes are made.
  ///
  /// ビルダーによりコード生成された[PrefsBase]を渡すことにより状態を保持された`SharedPreferences`を取得します。
  ///
  /// `SharedPreferences`の変更はすべて監視され、変更が行われた際、利用したウィジェットは更新されます。
  ///
  /// ```dart
  /// final prefs = ref.prefs(() => appPrefs); // Get the shared preferences.
  /// ```
  TPrefs prefs<TPrefs extends PrefsBase>(
    TPrefs Function() query,
  ) {
    return app.watch((ref) => query.call(), disposal: false);
  }
}
